import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';

import 'package:outline_material_icons/outline_material_icons.dart';

import 'package:spartathlon_app/views/CourseView.dart';
import 'package:spartathlon_app/views/ResultsView.dart';
import 'package:spartathlon_app/views/AthletesView.dart';
import 'package:spartathlon_app/views/SettingsView.dart';
import 'package:spartathlon_app/views/AboutView.dart';
import 'package:spartathlon_app/views/dashboard/DashboardView.dart';

/// Main view for Spartathlon app
///
/// 'Main' contains the broad frame the app is set it: the top and bottom app bar.
/// It enables switching between the four major screens.

class MainPage extends StatefulWidget {
  MainPage({Key key}) : super(key: key);

  @override
  MainPageState createState() => MainPageState();
}

class MainPageState extends State<MainPage> {
  int _currentIndex = 0;
  List<Widget> _childrenViews = [
    DashboardView(),
    CourseView(),
    ResultsView(),
    AthletesView(),
  ];

  @override
  Widget build(BuildContext context) {
    List<BottomNavigationBarItem> navBarIcons = List(4);

    navBarIcons[0] = BottomNavigationBarItem(
      icon: Icon(OMIcons.dashboard),
      title: Text('Dashboard'),
      backgroundColor: Theme.of(context).primaryColor,
    );
    navBarIcons[1] = BottomNavigationBarItem(
      icon: Icon(OMIcons.nearMe),
      title: Text('Course'),
      backgroundColor: Theme.of(context).primaryColor,
    );
    navBarIcons[2] = BottomNavigationBarItem(
      icon: Icon(OMIcons.insertChart),
      title: Text('Results'),
      backgroundColor: Theme.of(context).primaryColor,
    );
    navBarIcons[3] = BottomNavigationBarItem(
      icon: Icon(OMIcons.directionsRun),
      title: Text('Athletes'),
      backgroundColor: Theme.of(context).primaryColor,
    );

    return Scaffold(
      appBar: AppBar(
        title: Text('Spartathlon'),
        backgroundColor: Theme.of(context).primaryColor,
        actions: [
          IconButton(
              icon: Icon(OMIcons.settings),
              onPressed: () {
                Navigator.push(context,
                    CupertinoPageRoute(builder: (context) => SettingsView()));
              }),
        ],
      ),
      bottomNavigationBar: BottomNavigationBar(
        items: navBarIcons,
        currentIndex: _currentIndex,
        onTap: _onTabTapped,
      ),
      body: Container(
        child: _getChild(_currentIndex),
        //child: _childrenViews[_currentIndex],
      ),
    );
  }

  _onTabTapped(int index) {
    setState(() {
      _currentIndex = index;
    });
  }

  Widget _getChild(int i) {
    switch (i) {
      case 0:
        return DashboardView();
      case 1:
        return CourseView();
      case 2:
        return ResultsView();
      case 3:
        return AthletesView();
      default:
        return DashboardView();
    }
  }
}
