import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'package:spartathlon_app/AppStateContainer.dart';
import 'package:spartathlon_app/views/dashboard/BlogList.dart';
import 'package:spartathlon_app/views/dashboard/FavoriteAthletesSlider.dart';
import 'package:spartathlon_app/views/general/ErrorView.dart';
import 'package:spartathlon_app/views/general/LoadingView.dart';

class DashboardView extends StatefulWidget {
  DashboardView({Key key}) : super(key: key);

  @override
  _DashboardViewState createState() => _DashboardViewState();
}

class _DashboardViewState extends State<DashboardView> {
  @override
  Widget build(BuildContext context) {
    AppStateContainerState container = AppStateContainer.of(context);

    if (container.data.isLoading) {
      return LoadingView();
    }

    if (container.data.hasError) {
      return ErrorView(
        onRetry: container.loadData,
        text:
            'Error loading dashboard:\n' + 'Are you connected to the Internet?',
      );
    }

    return Scaffold(
      backgroundColor: Theme.of(context).scaffoldBackgroundColor,
      body: CustomScrollView(
        slivers: [
          // Workaround to prevent top header to be hovered
          SliverToBoxAdapter(child: Container(height: 0.1)),
          FavoriteAthletesSlider(
              favoriteAthletes: container.data.favoriteAthletes),
          BlogList(blogEntries: container.data.blogEntries),
        ],
      ),
    );
  }
}
